{
  description = "A minimal NixOS image with a custom driver.";

  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
  };

  outputs = {
    self,
    nixpkgs,
  }: {
    nixosConfigurations.myVM = nixpkgs.lib.nixosSystem {
      system = "x86_64-linux";

      modules = [
        ({
          pkgs,
          lib,
          config,
          ...
        }:
          with lib; {
            # Use minimal profile
            # imports = [ <nixpkgs/nixos/modules/profiles/minimal.nix> ];

            # Kernel customizations
            boot.kernelPackages = pkgs.linuxPackages_latest;

            networking.useDHCP = false;
            networking.interfaces.eth0.useDHCP = true;

            # Create user "test"
            services.getty.autologinUser = "test";
            users.users.test.isNormalUser = true;

            # Enable passwordless ‘sudo’ for the "test" user
            users.users.test.extraGroups = ["wheel"];
            security.sudo.wheelNeedsPassword = false;

            virtualisation.vmVariant.virtualisation.graphics = false;

            documentation = {
              enable = mkDefault false;
              doc.enable = mkDefault false;
              info.enable = mkDefault false;
              man.enable = mkDefault false;
              nixos.enable = mkDefault false;
            };

            environment = {
              # Perl is a default package.
              defaultPackages = mkDefault [];
              stub-ld.enable = mkDefault false;
            };

            programs = {
              # The lessopen package pulls in Perl.
              less.lessopen = mkDefault null;
              command-not-found.enable = mkDefault false;
            };

            # This pulls in nixos-containers which depends on Perl.
            boot.enableContainers = mkDefault false;

            services = {
              logrotate.enable = mkDefault false;
              udisks2.enable = mkDefault false;
            };

            xdg = {
              autostart.enable = mkDefault false;
              icons.enable = mkDefault false;
              mime.enable = mkDefault false;
              sounds.enable = mkDefault false;
            };

            # Add your driver module as source
            boot.extraModulePackages = let 
                kernel = config.boot.kernelPackages.kernel;
            in [
              (pkgs.stdenv.mkDerivation {
                name = "my-driver";
                src = ./my-driver;

                kernel = kernel.dev;
                kernelVersion = kernel.modDirVersion;

                buildInputs = [pkgs.nukeReferences];

                buildPhase = ''
                  # cd $sourceRoot
                  touch .bmd-support.o.cmd
                  make -C $kernel/lib/modules/$kernelVersion/build "M=$(pwd -P)" modules
                '';

                installPhase = ''
                  echo $kernelVersion
                  echo $kernel

                  mkdir -p $out/lib/modules/$kernelVersion/misc
                  for x in $(find . -name '*.ko'); do
                    nuke-refs $x
                    cp $x $out/lib/modules/$kernelVersion/misc/
                  done

                  # mkdir -p $out/lib/modules/${kernel.version}/kernel/drivers/my-driver/
                  # cp my-driver.ko $out/lib/modules/${kernel.version}/kernel/drivers/my-driver/
                '';

                meta = with pkgs.lib; {
                  description = "My custom Linux driver";
                  license = licenses.gpl2;
                  maintainers = [maintainers.yourName];
                };
              })
            ];

            # Networking and SSH to support testing
            networking.hostName = "nixos-vm";
            # services.openssh.enable = true;
          })
      ];
    };

    packages.x86_64-linux.linuxVM = self.nixosConfigurations.myVM.config.system.build.vm;
  };
}
